@@ -1,44 +1,51 @@
 from datetime import datetime
-from typing import Any, Dict, List, Optional
+from typing import Any, Dict, List
 
 import pydantic
 
 from python_on_whales.utils import DockerCamelModel, all_fields_optional
 
 
+@all_fields_optional
 class ObjectVersion(DockerCamelModel):
     index: int
 
 
+@all_fields_optional
 class NamedResourceSpec(DockerCamelModel):
     kind: str
     value: str
 
 
+@all_fields_optional
 class DiscreteResourceSpec(DockerCamelModel):
     kind: str
     value: int
 
 
+@all_fields_optional
 class AssignedGenericResources(DockerCamelModel):
-    named_resource_spec: Optional[NamedResourceSpec]
-    discrete_resource_spec: Optional[DiscreteResourceSpec]
+    named_resource_spec: NamedResourceSpec
+    discrete_resource_spec: DiscreteResourceSpec
 
 
+@all_fields_optional
 class ContainerStatus(DockerCamelModel):
     container_id: str = pydantic.Field(alias="ContainerID")
     pid: int = pydantic.Field(alias="PID")
-    exit_code: Optional[int]
+    exit_code: int
 
 
+@all_fields_optional
 class TaskStatus(DockerCamelModel):
     timestamp: datetime
     state: str
     message: str
-    err: Optional[str]
-    container_status: Optional[ContainerStatus]
+    err: str
+    container_status: ContainerStatus
 
 
+@all_fields_optional
 class LogDriver(DockerCamelModel):
     name: str
     options: Dict[str, str]
@@ -51,22 +58,26 @@ class NetworkAttachmentConfig(DockerCamelModel):
     driver_opts: Dict[str, str]
 
 
+@all_fields_optional
 class Platform(DockerCamelModel):
-    architecture: Optional[str]
-    os: Optional[str] = pydantic.Field(alias="OS")
+    architecture: str
+    os: str = pydantic.Field(alias="OS")
 
 
+@all_fields_optional
 class Spread(DockerCamelModel):
     spread_descriptor: str
 
 
+@all_fields_optional
 class Placement(DockerCamelModel):
-    constraints: Optional[List[str]]
-    preferences: Optional[List[Spread]]
-    max_replicas: Optional[int]
-    platforms: Optional[List[Platform]]
+    constraints: List[str]
+    preferences: List[Spread]
+    max_replicas: int
+    platforms: List[Platform]
 
 
+@all_fields_optional
 class RestartPolicy(DockerCamelModel):
     condition: str
     delay: int
@@ -74,12 +85,14 @@ class RestartPolicy(DockerCamelModel):
     window: int
 
 
+@all_fields_optional
 class PluginPrivilege(DockerCamelModel):
     name: str
     description: str
     value: List[str]
 
 
+@all_fields_optional
 class PluginSpec(DockerCamelModel):
     name: str
     remote: str
@@ -87,73 +100,79 @@ class PluginSpec(DockerCamelModel):
     plugin_privilege: List[PluginPrivilege]
 
 
+@all_fields_optional
 class ContainerSpec(DockerCamelModel):
     image: str
-    labels: Optional[Dict[str, str]]
-    command: Optional[List[str]]
-    args: Optional[List[str]]
-    hostname: Optional[str]
-    env: Optional[List[str]]
-    dir: Optional[str]
-    user: Optional[str]
-    groups: Optional[List[str]]
+    labels: Dict[str, str]
+    command: List[str]
+    args: List[str]
+    hostname: str
+    env: List[str]
+    dir: str
+    user: str
+    groups: List[str]
     privileges: Any
-    tty: Optional[bool] = pydantic.Field(alias="TTY")
-    open_stdin: Optional[bool]
-    read_only: Optional[bool]
-    mounts: Optional[List[Any]]
-    stop_signal: Optional[str]
-    stop_grace_period: Optional[int]
+    tty: bool = pydantic.Field(alias="TTY")
+    open_stdin: bool
+    read_only: bool
+    mounts: List[Any]
+    stop_signal: str
+    stop_grace_period: int
     health_check: Any
-    hosts: Optional[List[str]]
+    hosts: List[str]
     dns_config: Any
-    secrets: Optional[List[Any]]
-    configs: Optional[List[Any]]
-    isolation: Optional[str]
-    init: Optional[bool]
+    secrets: List[Any]
+    configs: List[Any]
+    isolation: str
+    init: bool
     sysctls: Any
 
 
+@all_fields_optional
 class NetworkAttachmentSpec(DockerCamelModel):
     container_id: str = pydantic.Field(alias="ContainerID")
 
 
+@all_fields_optional
 class ResourceObject(DockerCamelModel):
-    nano_cpus: Optional[int] = pydantic.Field(alias="NanoCPUs")
-    memory_bytes: Optional[int]
-    generic_resources: Optional[List[AssignedGenericResources]]
+    nano_cpus: int = pydantic.Field(alias="NanoCPUs")
+    memory_bytes: int
+    generic_resources: List[AssignedGenericResources]
 
 
+@all_fields_optional
 class Resources(DockerCamelModel):
-    limits: Optional[ResourceObject]
-    reservation: Optional[ResourceObject]
+    limits: ResourceObject
+    reservation: ResourceObject
 
 
+@all_fields_optional
 class TaskSpec(DockerCamelModel):
     # TODO: set types for Any
-    plugin_spec: Optional[PluginSpec]
-    container_spec: Optional[ContainerSpec]
-    network_attachment_spec: Optional[NetworkAttachmentSpec]
+    plugin_spec: PluginSpec
+    container_spec: ContainerSpec
+    network_attachment_spec: NetworkAttachmentSpec
     resources: Resources
     restart_policy: Any
     placement: Placement
-    force_update: Optional[int]
-    runtime: Optional[str]
-    networks: Optional[List[NetworkAttachmentConfig]]
-    log_driver: Optional[LogDriver]
+    force_update: int
+    runtime: str
+    networks: List[NetworkAttachmentConfig]
+    log_driver: LogDriver
 
 
+@all_fields_optional
 class TaskInspectResult(DockerCamelModel):
     id: str = pydantic.Field(alias="ID")
     version: ObjectVersion
     created_at: datetime
     updated_at: datetime
-    name: Optional[str]
-    labels: Optional[Dict[str, str]]
+    name: str
+    labels: Dict[str, str]
     spec: TaskSpec
     service_id: str = pydantic.Field(alias="ServiceID")
-    slot: Optional[int]
-    node_id: Optional[str] = pydantic.Field(alias="NodeID")
-    assigned_generic_resources: Optional[List[AssignedGenericResources]]
+    slot: int
+    node_id: str = pydantic.Field(alias="NodeID")
+    assigned_generic_resources: List[AssignedGenericResources]
     status: TaskStatus
     desired_state: str
